#!/bin/bash

# ---------------------------------------------------------------------------- #
# This file is part of gsbuild
# Copyright (C) 2005 Greg Schafer <gschafer@zip.com.au>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Name:      gsbuild_cross_all.sh
# Synopsis:  A simple wrapper around gsbuild_cross.sh to facilitate building
#            toolchains for multiple architecture/threadlib combinations.
# ---------------------------------------------------------------------------- #

case "$BASH_VERSION" in
2.05[b-z]* | [3-9].*) ;;
*)	echo >&2
	echo "ERROR: Need bash version 2.05b or greater!" >&2
	echo "       Please see docs for info on how to proceed." >&2
	echo >&2
	exit 1 ;;
esac

# Be where we wanna be
if [[ $0 == */* ]]; then
	cd ${0%/*}/
fi

CURDIR=`pwd`
test -z "$CROSS_PFX" && { echo "ERROR: CROSS_PFX unset. Bailing.." >&2; exit 1; }

ARCHES_LIST="
  powerpc s390 sparc mips i686 sh3 sh4 arm m68k
  powerpc64 s390x sparc64 mips64 x86_64 ia64 alpha"
  #hppa cris

THREAD_LIBS="linuxthreads nptl"

NPTL_ARCHES="
  powerpc s390 sparc i686 sh3 sh4
  powerpc64 s390x x86_64 ia64 alpha"

for TL in $THREAD_LIBS; do
	for T in $ARCHES_LIST; do
		TARGET=$T-linux
		BASE_TARGET=${TARGET%%-*}
		THREAD_LIB=$TL
		CROSS_TOOLS_PFX=${CROSS_PFX}/${BASE_TARGET}/${THREAD_LIB}
		SYSROOT=${CROSS_TOOLS_PFX}/sysroot
		export TARGET BASE_TARGET THREAD_LIB CROSS_TOOLS_PFX SYSROOT
		bash $CURDIR/gsbuild_cross.sh || echo $T $TL FAILED >> FAILED
	done
done

echo All Finished!
exit 0
